#!python
"""
This file contains the base Classifier class, which your classifier (let's call it Challenger) will inherit from.  You're free to add other classes, methods and functions to your module, but for the competition, you must define Challenger.train(X, Y) and Challenger.test(X) and it must pass all the unittests in unittest_classifier.py

DO NOT CHANGE ANYTHING IN THIS FILE.
"""
from __future__ import division

import cPickle as pickle
import time
from numpy import *



class UntrainedError(Exception):
    """
    throw this exception if we try to call test() on an untrained classifier
    """
    def __init__(self):
        pass
        
        
class Classifier(object):
    """  
    Base class for all competition classifiers.  
    """
    
    def __init__(self, sname="", cname="", about=""):
        """
        This is the base class constructor.
        
            sname   student name
            cname   name of the classifier
            about   additional information (version number, etc)
        """
        super(Classifier, self).__init__()
        self.sname = sname
        self.cname = cname
        self.about = about

    def train(self, X, Y):
        """
        You must implement your own train method that calls this one.
        """
        raise NotImplementedError, "method not implemented in base class"
        
    def test(self, X):
        """
        You must implement your own test method that calls this one.
        """
        raise NotImplementedError, "method not implemented in base class"
        


def scoreClassifier(cfr):
    """
    Score the classifier against a predefined data set.
    """
    print 'COMPETITOR: %s [%s] by %s' % (cfr.cname, cfr.about, cfr.sname)
    
    train = pickle.load(open('trainExperimental.pkl'))    
    tic = time.time()
    cfr.train(train)
    print '\ttrain\t %.2fs' % (time.time()-tic)
    
    tic = time.time()
    test = pickle.load(open('testExperimental.pkl'))
    testX = [x for _,x in test]
    testY = [y for y,_ in test]
    H = cfr.test(testX)
    print '\ttest\t %.2fs' % (time.time()-tic)
    
    assert len(H)==len(testY)
    error = sum(1 for h,y in zip(H, testY) if h != y) / len(H)
    print '\terror\t %.4f' % error
