#!python
"""
This file supplies some basic unittest to help you develop your classifier for the competition.  This is NOT the full suite of tests used in the competition, but if your classifier doesn't pass these tests, it will be disqualified.  This is a good place to add your own tests to aid development.  You don't need to submit your unit tests or results -- this is purely to make things easier for development.
"""

# python and numpy imports
import unittest
from numpy import *
import cPickle as pickle

# local imports
import competition
from exampleclassifier import ExampleClassifier, UntrainedError


class TestSuppliedClassifiers(unittest.TestCase):
    # A test case is a class for bundling tests.  For *each* test method in the
    # test case, the environment will be initialized with setUp, the test will
    # be run, and then tearDown will be called.  You are not required to define 
    # setUp and tearDown.
    def setUp(self):
        pass
    
    def tearDown(self):
        pass
    
    # Any method that begins with 'test' will be run by the test suite and a
    # report generated.  You can quickly deactive a test by putting a different
    # character at the beginning of the method name.
    def testBaseClassifier(self):
        # make sure base classifier behaves as expected
        sname = "tester"
        cname = "base"
        about = "v1.0"
        
        base = competition.Classifier(sname, cname, about)
        
        self.assertEqual(base.sname, sname)
        self.assertEqual(base.cname, cname)
        self.assertEqual(base.about, about)
        
        self.assertRaises(NotImplementedError, base.train, [], [])
        self.assertRaises(NotImplementedError, base.test, [])
    
    def testExampleClassifier(self):
        # make sure example classifier works as expected

        sname = "tester"
        cname = "example"
        about = "v1.0"
        
        ex = ExampleClassifier(sname, cname, about, debug=False)
    
        self.assertEqual(ex.sname, sname)
        self.assertEqual(ex.cname, cname)
        self.assertEqual(ex.about, about)
        
        self.assertRaises(UntrainedError, ex.test, [])
        
        # just use a subset of the data to make it faster...
        Z = pickle.load(open('trainExperimental.pkl'))
        ex.train(Z[:10])
        
        self.assertNotEqual(ex.feature, None)
        
        H = ex.test((x for _,x in Z[10:20]))
        
        self.assertEqual(len(H), 10)
        for h in H:
            self.assert_(isscalar(h))


class TestChallenger(unittest.TestCase):
    
    # Edit the file so that this tests your classifier, and add whaetver tests
    # you see fit.
    
    def setUp(self):
        pass
        
    def testChallenger(self):        
        # tests your classifier must pass.  we suggest you start with the tests
        # from testExampleClassifier and add your own as needed.
        pass


if __name__ == '__main__':
    tests = [TestSuppliedClassifiers, TestChallenger]

    for test in tests:
        suite = unittest.TestLoader().loadTestsFromTestCase(test)
        unittest.TextTestRunner(verbosity=2).run(suite)
            